@@ -7,7 +7,8 @@
 #    http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
@@ -21,7 +22,7 @@ from gitfs.log import log
 class FetchWorker(Peasant):
     name = 'FetchWorker'
 
-    def run(self):
+    def work(self):
         while True:
             fetch.wait(self.timeout)
 
